==> quidproquo-actionprocessor-awslambda-0.0.219.tgz: package/lib/esm/getActionProcessor/core/system/getExecuteStoryActionProcessor.js <==
import { SystemActionType, createRuntime, actionResultError, ErrorTypeEnum, actionResult, QpqRuntimeType, qpqCoreUtils, } from 'quidproquo-core';
import { randomGuid } from './../../../awsLambdaUtils';
export const getDateNow = () => new Date().toISOString();
const getProcessExecuteStory = (qpqConfig, dynamicModuleLoader) => {
    const moduleName = qpqCoreUtils.getApplicationModuleName(qpqConfig);
    return async (payload, session, actionProcessors, logger) => {
        let module = await dynamicModuleLoader(payload.src);
        if (module === null) {
            return actionResultError(ErrorTypeEnum.NotFound, `Module not found [${payload.src}]`);
        }
        const story = module[payload.runtime];
        if (!story) {
            return actionResultError(ErrorTypeEnum.NotFound, `[${payload.runtime}] not found in module [${payload.src}]`);
        }
        const resolveStory = createRuntime(qpqConfig, {
            context: payload.storySession?.context || session.context,
            depth: (payload.storySession?.depth || session.depth || 0) + 1,
            accessToken: payload.storySession?.accessToken || session.accessToken,
            correlation: payload.storySession?.correlation || session.correlation,
        }, actionProcessors, getDateNow, logger, 
        // TODO: Share this logic.
        `${moduleName}::${randomGuid()}`, QpqRuntimeType.EXECUTE_STORY, [`${payload.src}::${payload.runtime}`]);
        const storyResult = await resolveStory(story, payload.params);
        if (storyResult.error) {
            const stack = `${payload.src}::${payload.runtime}`;
            return actionResultError(storyResult.error.errorType, storyResult.error.errorText, storyResult.error.errorStack ? `${stack} -> [${storyResult.error.errorStack}]` : stack);
        }
        return actionResult(storyResult.result);
    };
};
export default (qpqConfig, dynamicModuleLoader) => {
    return {
        [SystemActionType.ExecuteStory]: getProcessExecuteStory(qpqConfig, dynamicModuleLoader),
    };
};

==> quidproquo-actionprocessor-awslambda-0.0.221.tgz: package/lib/esm/getActionProcessor/core/system/getExecuteStoryActionProcessor.js <==
import { SystemActionType, createRuntime, actionResultError, ErrorTypeEnum, actionResult, QpqRuntimeType, qpqCoreUtils, } from 'quidproquo-core';
import { randomGuid } from './../../../awsLambdaUtils';
export const getDateNow = () => new Date().toISOString();
const getProcessExecuteStory = (qpqConfig, dynamicModuleLoader) => {
    const moduleName = qpqCoreUtils.getApplicationModuleName(qpqConfig);
    return async (payload, session, actionProcessors, logger) => {
        console.log('Trying to load module');
        let story = await dynamicModuleLoader(payload.runtime);
        console.log('After - Trying to load module');
        if (!story) {
            console.log('No story');
            return actionResultError(ErrorTypeEnum.NotFound, `Unable to dynamically load: [${payload.runtime}]`);
        }
        const resolveStory = createRuntime(qpqConfig, {
            context: payload.storySession?.context || session.context,
            depth: (payload.storySession?.depth || session.depth || 0) + 1,
            accessToken: payload.storySession?.accessToken || session.accessToken,
            correlation: payload.storySession?.correlation || session.correlation,
        }, actionProcessors, getDateNow, logger, 
        // TODO: Share this logic.
        `${moduleName}::${randomGuid()}`, QpqRuntimeType.EXECUTE_STORY, [payload.runtime]);
        const storyResult = await resolveStory(story, payload.params);
        if (storyResult.error) {
            return actionResultError(storyResult.error.errorType, storyResult.error.errorText, storyResult.error.errorStack ? `${payload.runtime} -> [${storyResult.error.errorStack}]` : payload.runtime);
        }
        return actionResult(storyResult.result);
    };
};
export default (qpqConfig, dynamicModuleLoader) => {
    return {
        [SystemActionType.ExecuteStory]: getProcessExecuteStory(qpqConfig, dynamicModuleLoader),
    };
};
